summaryrefslogtreecommitdiff
path: root/zwgc/String
diff options
context:
space:
mode:
authorGravatar Richard Basch <probe@mit.edu>1993-11-19 11:10:00 +0000
committerGravatar Richard Basch <probe@mit.edu>1993-11-19 11:10:00 +0000
commit574d3bb9bee6bccfd8dedf2908fd963d17cd549c (patch)
tree58ff67231eb98bcd790622f5a0ca5c569eb3fc2a /zwgc/String
parent1e39466d7ab63d4a92c771ef5f49651352813ad2 (diff)
Change bcopy to memcpy [ANSI]
Diffstat (limited to 'zwgc/String')
-rw-r--r--zwgc/String/new_string.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/zwgc/String/new_string.c b/zwgc/String/new_string.c
index ea0f894..5009b06 100644
--- a/zwgc/String/new_string.c
+++ b/zwgc/String/new_string.c
@@ -69,7 +69,7 @@ string string__CreateFromData(data, length)
result = (string)malloc(length+1);
assert(result);
- bcopy(data, result, length);
+ (void) memcpy(result, data, length);
result[length] = 0;
return(result);
@@ -93,7 +93,7 @@ string string__Copy(s)
result = (string)malloc(length);
assert(result);
- bcopy(s, result, length);
+ (void) memcpy(result, s, length);
return(result);
}
@@ -117,8 +117,8 @@ string string__Concat(a, b)
result = (string)malloc(result_size);
assert(result);
- bcopy(a, result, a_length);
- bcopy(b, result+a_length, b_size);
+ (void) memcpy(result, a, a_length);
+ (void) memcpy(result+a_length, b, b_size);
return(result);
}
@@ -132,7 +132,7 @@ string string__Concat(a, b)
* temp = string_Concat(a,b);
* free(a);
* return(temp);
* only faster. I.e., uses realloc instead of malloc+bcopy.
*/
string string__Concat2(a, b)
@@ -147,7 +147,7 @@ string string__Concat2(a, b)
a = (string)realloc(a, a_length+b_size);
assert(a);
- bcopy(b, a+a_length, b_size);
+ (void) memcpy(a+a_length, b, b_size);
return(a);
}
@@ -132,7 +132,7 @@ string string__Concat(a, b)
* free(a);
* return(temp);
- * only faster. I.e., uses realloc instead of malloc+bcopy.
+ * only faster. I.e., uses realloc instead of malloc+memcpy.
*/
string string__Concat2(a, b)